@@ -3,7 +3,6 @@
    is especially important to not use polymorphic comparisons, since we are moving more
    and more to code that doesn't have them in scope. *)
 
-
 open Base
 open Ppxlib
 open Ast_builder.Default
@@ -465,7 +464,7 @@ module Gen_str = struct
           let body =
             if Variant_constructor.is_gadt v
             then locally_abstract_match loc cases ~variant_ty
-            else pexp_function ~loc cases
+            else pexp_function_cases ~loc cases
           in
           [%stri let [%p pvar ~loc name] = [%e body] [@@warning "-4"]]
         in
@@ -625,8 +624,8 @@ module Gen_str = struct
               acc
               [ ( Labelled variant_name
                 , match V.args variant with
-                | [] -> [%expr fun _ -> [%e evar ~loc (variant_name ^ "_gen__")] ()]
-                | _ :: _ -> [%expr fun _ -> [%e evar ~loc (variant_name ^ "_gen__")]] )
+                  | [] -> [%expr fun _ -> [%e evar ~loc (variant_name ^ "_gen__")] ()]
+                  | _ :: _ -> [%expr fun _ -> [%e evar ~loc (variant_name ^ "_gen__")]] )
               ])
         in
         [%expr [%e map], compile_acc__]
@@ -678,7 +677,7 @@ module Gen_str = struct
     let body =
       if List.exists variants ~f:Variant_constructor.is_gadt
       then locally_abstract_match loc cases ~variant_ty
-      else pexp_function ~loc cases
+      else pexp_function_cases ~loc cases
     in
     [%stri let to_rank = [%e body]]
   ;;
@@ -690,7 +689,7 @@ module Gen_str = struct
     let body =
       if List.exists variants ~f:Variant_constructor.is_gadt
       then locally_abstract_match loc cases ~variant_ty
-      else pexp_function ~loc cases
+      else pexp_function_cases ~loc cases
     in
     [%stri let to_name = [%e body]]
   ;;
